==> metatrader5EasyT-0.1.9.tar.gz: metatrader5EasyT-0.1.9/README.md <==
![PyPI - Downloads](https://img.shields.io/pypi/dm/metatrader5EasyT)
![PyPI](https://img.shields.io/pypi/v/metatrader5EasyT)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/metatrader5EasyT)
![PyPI - License](https://img.shields.io/pypi/l/metatrader5EasyT)

# metatrader5EasyT

- easyT,
  - easyTo trade,
    - easyTo use!
  
# WARNING!

Now that I have your attention I would like you to reflect about the fact that **$1.00 Dollar** might be **not** 
that **much** to you, but **you, an incredible person**, combined to other's **amazing Sponsors**, can **finance** this 
project, and it will **allows me** to constantly **improve and maintain** it, **and, I am not asking that much**.

Here is my [Patreon](https://www.patreon.com/joaopeuko) link.

  - _Yeah, I would like to do that, but I do not have that kind of money._ 

That is Ok, and, there are many ways you can help me, here is a list:

  - **Star** this project on GitHub.
  - **Share** this project.
  - **Open an account with Binance referral link**:
    - When you open an account on Binance you help me when you trade!
    - Some of your tax paid returns for you and part goes for me.
    - Below you can see the percentage cash back for me and for you, and you trade:
        
    |For me | For you | Link|
    |:--------| :----:  |  ---:|
    | 10%| 10%     | https://accounts.binance.com/en/register?ref=IBNF8RAW | 
    | 15%| 5%      | https://accounts.binance.com/en/register?ref=D11OJ6NP | 
    | 20%| 0%      | https://accounts.binance.com/en/register?ref=SAUNZ26X | 
      - You can find more information about the **Binance** referral link [here](https://www.binance.com/en/support/faq/88659d2ea54c40cf82a22400207ffe30)
      
  - And, there are **Ads** in all the documentations, that hopefully, will help me finance this project.

# Installation:


Keep in mind that it will only work on Windows.

```python
pip install metatrader5EasyT
```

# Libraries Documentation

All the Libraries Documentation are linked below:

- [easyT]()
  - [metatrader5EasyT](https://joaopeuko.github.io/metatrader5EasyT/)

For this specific project, is this one [metatrader5EasyT](https://joaopeuko.github.io/metatrader5EasyT/).

==> metatrader5EasyT-0.1.11.tar.gz: metatrader5EasyT-0.1.11/README.md <==
![PyPI - Downloads](https://img.shields.io/pypi/dm/metatrader5EasyT)
![PyPI](https://img.shields.io/pypi/v/metatrader5EasyT)
![PyPI - Wheel](https://img.shields.io/pypi/wheel/metatrader5EasyT)
![PyPI - License](https://img.shields.io/pypi/l/metatrader5EasyT)

# metatrader5EasyT

- easyT,
  - easyTo trade,
    - easyTo use!
  
# WARNING!

Now that I have your attention I would like you to reflect about the fact that **$1.00 Dollar** might be **not** 
that **much** to you, but **you, an incredible person**, combined to other's **amazing Sponsors**, can **finance** this 
project, and it will **allows me** to constantly **improve and maintain** it, **and, I am not asking that much**.

Here is my [Patreon](https://www.patreon.com/joaopeuko) link.

  - _Yeah, I would like to do that, but I do not have that kind of money._ 

That is Ok, and, there are many ways you can help me, here is a list:

  - **Star** this project on GitHub.
  - **Share** this project.
  - **Open an account with Binance referral link**:
    - When you open an account on Binance you help me when you trade!
    - Some of your tax paid returns for you and part goes for me.
    - Below you can see the percentage cash back for me and for you, and you trade:
        
    |For me | For you | Link|
    |:--------| :----:  |  ---:|
    | 10%| 10%     | https://accounts.binance.com/en/register?ref=IBNF8RAW | 
    | 15%| 5%      | https://accounts.binance.com/en/register?ref=D11OJ6NP | 
    | 20%| 0%      | https://accounts.binance.com/en/register?ref=SAUNZ26X | 
      - You can find more information about the **Binance** referral link [here](https://www.binance.com/en/support/faq/88659d2ea54c40cf82a22400207ffe30)
      
  - And, there are **Ads** in all the documentations, that hopefully, will help me finance this project.

# Installation:


Keep in mind that it will **only work on Windows**.

```python
pip install metatrader5EasyT
```

If you want to know **how to use** and **examples**, please, see the link to the **documentation** below.  
All the information will be there.

# Libraries Documentation

All the Libraries Documentation and useful links are linked below:

- easyT
  - metatrader5EasyT - [Documentation](https://joaopeuko.github.io/metatrader5EasyT/) - [GitHub](https://github.com/Joaopeuko/metatrader5EasyT) - [Pypi](https://pypi.org/project/metatrader5EasyT/)
- Mql5-Python-Integration - [GitHub](https://joaopeuko.github.io/Mql5-Python-Integration/)

The documentation for this specific project is this one [metatrader5EasyT](https://joaopeuko.github.io/metatrader5EasyT/).
